"""This is the sample module for didiatic purpose only
    It is not advised to use this in production """


def print_lol(the_list):
    
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item)
        else:
            print(each_item)





from distutils.core import setup

setup(
        name = 'nexter',
        version = '1.0.0',
        py_modules = ['nexter'],
        author = 'basileis',
        author_email = 'basileis@gmail.com',
        url = 'http://basileis.com',
        description = 'New module for didiatic purpose',
    )

